#!/bin/bash
#
# Copyright 2016 Google Inc. All rights reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http:#www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

set -u

mk="$@"

cat <<EOF > Makefile
all: FOO = bar
.KATI_READONLY = FOO
all:
EOF

if echo "${mk}" | grep -q "^make"; then
  # Make doesn't support .KATI_READONLY
  echo "Makefile:2: *** unknown variable: FOO"
else
  ${mk} 2>&1 && echo "Clean exit"
fi
